#[non_exhaustive]pub struct UnsafeMmap {}Available on crate feature
full only.Trait Implementations
Sourceimpl Default for UnsafeMmap
impl Default for UnsafeMmap
Sourcefn default() -> UnsafeMmap
fn default() -> UnsafeMmap
Returns the “default value” for a type. Read more
Sourceimpl Mappable for UnsafeMmap
impl Mappable for UnsafeMmap
Sourcefn virtual_size(&self, frame_count: usize) -> NonZero<usize>
fn virtual_size(&self, frame_count: usize) -> NonZero<usize>
The number of pages required to create a mapping with
frame_count framesSourcefn base_virtual_offset(&self) -> isize
fn base_virtual_offset(&self) -> isize
The number of pages to offset the physical memory into the allocated virtual memory