pub trait Mappable {
// Required methods
fn virtual_size(&self, frame_count: usize) -> NonZero<usize>;
fn base_virtual_offset(&self) -> isize;
}Available on crate feature
full only.Expand description
Basic operations to decide how to map memory together.
Implementations of this can be used to instantiate a [RawMapping].
Required Methods
Sourcefn virtual_size(&self, frame_count: usize) -> NonZero<usize>
fn virtual_size(&self, frame_count: usize) -> NonZero<usize>
The number of pages required to create a mapping with frame_count frames
Sourcefn base_virtual_offset(&self) -> isize
fn base_virtual_offset(&self) -> isize
The number of pages to offset the physical memory into the allocated virtual memory